import streamlit as st
import pandas as pd
import numpy as np
import subprocess
import glob, sys, time, statistics, os.path, random
from pathlib import Path
import psutil
import plotly.graph_objects as go
from taxontabletools2.start import TTT_variables
from taxontabletools2.utilities import load_df
from taxontabletools2.utilities import collect_replicates
from taxontabletools2.utilities import collect_sample_stats
from taxontabletools2.basic_stats import basic_stats_reads
from taxontabletools2.basic_stats import basic_stats_OTUs
from taxontabletools2.basic_stats import taxonomic_resolution
from taxontabletools2.basic_stats import taxonomic_richness
from taxontabletools2.utilities import collect_traits
from taxontabletools2.utilities import strip_traits
from taxontabletools2.utilities import check_replicates
from taxontabletools2.table_processing import replicate_merging
from taxontabletools2.table_processing import negative_control_subtraction
from taxontabletools2.table_processing import read_based_filter
from taxontabletools2.table_processing import read_based_normalisation
from taxontabletools2.table_processing import taxonomic_filtering
from taxontabletools2.table_processing import sample_filtering
from taxontabletools2.table_conversion import presence_absence_table
from taxontabletools2.table_conversion import simplify_table
from taxontabletools2.table_conversion import add_traits_from_file
from taxontabletools2.table_conversion import add_traits_from_file
from taxontabletools2.table_conversion import rename_samples
from taxontabletools2.table_conversion import sort_samples
from taxontabletools2.taxontable_conversion import taxon_table_converter_ttt
from taxontabletools2.taxontable_conversion import taxon_table_converter_qiime2
import streamlit as st
from taxontabletools2.start import start

# Call the sidebar function
settings = start()
users_settings = settings['new_user_preferences_dict']

## Page title
st.write(""" ## Table conversion """)

# Ensure the session state variables are retained across subpages
if 'TaXon_table_df' not in st.session_state:
    error1, error2, error3 = st.columns(3)
    with error2:
        st.write('##### Please load a TaXon table to continue!')

elif 'TaXon_table_xlsx' not in st.session_state:
    error1, error2, error3 = st.columns(3)
    with error2:
        st.write('##### Please load a TaXon table to continue!')

elif st.session_state['TaXon_table_df'].empty == True:
    error1, error2, error3 = st.columns(3)
    with error2:
        st.write('##### Please check your TaXon table. It seems to be empty!')

elif st.session_state['TaXon_table_xlsx'].is_file() == False:
    error1, error2, error3 = st.columns(3)
    with error2:
        st.write('##### The TaXon table does not exist in the selected project folder!')

########################################################################################################################

else:
    st.write('### Presence absence table')
    with st.expander("See more"):
        b1, b2 = st.columns(2)
        with b1:
            st.write('Converts reads to presence/absence format (1/0).')
        with b2:
            pass

        if st.button('Convert to presence/absence table'):
            presence_absence_table(st.session_state['TaXon_table_xlsx'], st.session_state['TaXon_table_df'], st.session_state['samples'], st.session_state['metadata_df'], st.session_state['traits_df'])
            st.success('Converted table to presence/absence data. Please remember to reload the TaXon table!')

    ########################################################################################################################
    st.write('### Simplify table')
    with st.expander("See more"):
        d1, d2 = st.columns(2)
        with d1:
            st.write(f'This module will merge all {st.session_state["clustering_unit"]} with identical taxonomic assignments into a single operational taxonomic unit, called \"spOTU\".')
            st.write('Please not that previously assigned traits must be re-added again. Also, sequences will be removed and the similarity will be set to 100.')
        with d2:
            pass
        if st.button('Simplify table'):
            simplify_table(st.session_state['TaXon_table_xlsx'], st.session_state['TaXon_table_df'], st.session_state['samples'], st.session_state['metadata_df'], st.session_state['traits_df'])
            st.success('Simplified table. Please remember to reload the TaXon table!')

    ########################################################################################################################
    st.write('### Add traits from file')
    with st.expander("See more"):
        e1, e2 = st.columns(2)
        with e1:
            new_traits_file = st.file_uploader('Upload your .xlsx file that contains the traits!')
        with e2:
            if new_traits_file != None:
                st.session_state['new_traits_df'] = pd.read_excel(new_traits_file)
                st.selectbox('Select taxonomic level:',
                             [i for i in st.session_state['new_traits_df'] if i in available_taxonomic_levels_list])
                st.multiselect('Select traits to add:',
                             [i for i in st.session_state['new_traits_df'] if i not in available_taxonomic_levels_list])

        if st.button('Add traits to table'):
            pass
            st.success('Text')

    ########################################################################################################################
    st.write('### Sort samples')
    with st.expander("See more"):
        st.write('Sort samples based on the current sorting of the metadata table.')
        if st.button('Sort samples'):
            sort_samples(st.session_state['TaXon_table_xlsx'], st.session_state['TaXon_table_df'], st.session_state['samples'], st.session_state['metadata_df'], st.session_state['traits_df'])
            st.success('Samples were sorted according to the metadata table!')

    ########################################################################################################################
    st.write('### Rename samples')
    with st.expander("See more"):
        g1, g2 = st.columns(2)
        with g1:
            available_metadata = st.session_state['metadata_df'].columns.tolist()[1:]
            selected_metadata = st.selectbox('Select metadata to test:', available_metadata)
        with g2:
            pass

        st.write(f'Rename samples based on the "{selected_metadata}" column.')
        if st.button('Rename samples'):
            rename_samples(st.session_state['TaXon_table_xlsx'], st.session_state['TaXon_table_df'], st.session_state['samples'], st.session_state['metadata_df'], st.session_state['traits_df'], selected_metadata)
            st.success(f'Samples were renamed based on the "{selected_metadata}" column!')







import streamlit as st
import pandas as pd
import numpy as np
import subprocess
import glob, sys, time, statistics, os.path, random
from pathlib import Path
import psutil
import plotly.graph_objects as go
from taxontabletools2.start import TTT_variables
from taxontabletools2.utilities import load_df
from taxontabletools2.utilities import collect_replicates
from taxontabletools2.utilities import collect_sample_stats
from taxontabletools2.basic_stats import basic_stats_reads
from taxontabletools2.basic_stats import basic_stats_OTUs
from taxontabletools2.basic_stats import taxonomic_resolution
from taxontabletools2.basic_stats import taxonomic_richness
from taxontabletools2.utilities import collect_traits
from taxontabletools2.utilities import strip_traits
from taxontabletools2.table_processing import replicate_merging
from taxontabletools2.table_processing import negative_control_subtraction
from taxontabletools2.table_processing import read_based_filter
from taxontabletools2.table_processing import read_based_normalisation
from taxontabletools2.table_processing import taxonomic_filtering
from taxontabletools2.table_processing import sample_filtering
from taxontabletools2.taxontable_conversion import taxon_table_converter_ttt
from taxontabletools2.taxontable_conversion import taxon_table_converter_qiime2
from taxontabletools2.sample_comparison import venn
from taxontabletools2.diversity_analyses import alpha_boxplot
from taxontabletools2.diversity_analyses import distance_matrix
from taxontabletools2.ordination_analyses import pcoa_analysis
from taxontabletools2.ordination_analyses import display_pcoa
import streamlit as st
from taxontabletools2.start import start

# Call the sidebar function
settings = start()
user_settings = settings['new_user_preferences_dict']

## Page title
st.write(""" ## Ordination analyses """)

# Ensure the session state variables are retained across subpages
if 'TaXon_table_df' not in st.session_state:
    error1, error2, error3 = st.columns(3)
    with error2:
        st.write('##### Please load a TaXon table to continue!')

elif 'TaXon_table_xlsx' not in st.session_state:
    error1, error2, error3 = st.columns(3)
    with error2:
        st.write('##### Please load a TaXon table to continue!')

elif st.session_state['TaXon_table_df'].empty == True:
    error1, error2, error3 = st.columns(3)
    with error2:
        st.write('##### Please check your TaXon table. It seems to be empty!')

elif st.session_state['TaXon_table_xlsx'].is_file() == False:
    error1, error2, error3 = st.columns(3)
    with error2:
        st.write('##### The TaXon table does not exist in the selected project folder!')

########################################################################################################################

else:
    st.write('### Ordination analyses')

    st.write('### Principle Coordinate Analysis (PCoA)')

    ordination1, ordination2, ordination3 = st.columns(3)

    with ordination1:
        available_metadata = ['All samples']  + st.session_state['metadata_df'].columns.tolist()[1:]
        selected_metadata = st.selectbox('Select metadata to test:', available_metadata)

    with ordination2:
        taxonomic_level = st.selectbox('Select taxonomic level:', st.session_state['available_taxonomic_levels_list'], index=5)

    with ordination3:
        distance_metric = st.selectbox('Select metric: ', ['Jaccard', 'Braycurtis'], index=0)

    if st.button(f'Calculate {taxonomic_level} PCoA for {selected_metadata}, based on {distance_metric} similarity.'):

        st.session_state['pcoa_df'], st.session_state['axes_dict'], st.session_state['anosim_result'], st.session_state['pcoa_metadata']  = pcoa_analysis(
            st.session_state['path_to_outdirs'],
            st.session_state['TaXon_table_xlsx'],
            st.session_state['TaXon_table_df'],
            st.session_state['samples'],
            st.session_state['metadata_df'],
            selected_metadata,
            st.session_state['traits_df'],
            '',
            user_settings,
            {'selected_metadata': selected_metadata, 'taxonomic_level': taxonomic_level, 'metric': distance_metric}
        )

    if 'pcoa_df' not in st.session_state:
        st.error('Please first calculate the PCoA.')

    else:
        axis_select_1, axis_select_2, axis_select_3, axis_select_4 = st.columns(4)

        select_dict = {key:f'{key} ({round(values, 2)}%)' for key, values in st.session_state['axes_dict'].items()}

        with axis_select_1:
            axis_1 = st.selectbox('Axis 1', select_dict.values(), index=0)
        with axis_select_2:
            axis_2 = st.selectbox('Axis 2', select_dict.values(), index=1)
        with axis_select_3:
            axis_3 = st.selectbox('Axis 3', ['Not selected'] + list(select_dict.values()), index=0)
        with axis_select_4:
            draw_outlines = st.selectbox('Draw outlines according to metadata', [True, False], index=0)

        selected_axes = [axis_1, axis_2, axis_3]

        if st.button('Display PCoA'):

            fig_pcoa = display_pcoa(
                st.session_state['pcoa_df'],
                st.session_state['axes_dict'],
                selected_axes,
                user_settings,
                {'selected_metadata': selected_metadata, 'taxonomic_level': taxonomic_level, 'metric': distance_metric,
                 'draw_outlines': draw_outlines, 'anosim_result':st.session_state['anosim_result'], 'pcoa_metadata':st.session_state['pcoa_metadata']
                 }
                )

            st.plotly_chart(fig_pcoa, use_container_width=True, config=st.session_state['config'])

            fig_pcoa.write_image('/Users/tillmacher/Downloads/test.pdf')


import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="taxontabletools2", # Replace with your own username
    version="2.0.4",
    author="Till-Hendrik Macher",
    author_email="macher@uni-trier.de",
    description="taxontabletools - A comprehensive, platform-independent graphical user interface software to explore and visualise DNA metabarcoding data",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/pypa/taxontabletools2",
    packages=setuptools.find_packages(),
    license = 'MIT',
    install_requires = [
        "altair==5.4.1",
        "attrs==24.2.0",
        "blinker==1.8.2",
        "cachetools==5.5.0",
        "contourpy==1.3.0",
        "cycler==0.12.1",
        "et-xmlfile==1.1.0",
        "fonttools==4.54.1",
        "gitdb==4.0.11",
        "gitpython==3.1.43",
        "jinja2==3.1.4",
        "jsonschema==4.23.0",
        "jsonschema-specifications==2024.10.1",
        "kaleido==0.2.1",
        "kiwisolver==1.4.7",
        "levenshtein==0.26.0",
        "markdown-it-py==3.0.0",
        "markupsafe==3.0.1",
        "matplotlib==3.9.2",
        "matplotlib-venn==1.1.1",
        "mdurl==0.1.2",
        "narwhals==1.9.2",
        "openpyxl==3.1.5",
        "pillow==10.4.0",
        "plotly==5.24.1",
        "protobuf==5.28.2",
        "psutil==6.0.0",
        "pyarrow==17.0.0",
        "pydeck==0.9.1",
        "pymannkendall==1.4.3",
        "pyparsing==3.1.4",
        "python-dateutil==2.9.0.post0",
        "pytz==2024.2",
        "rapidfuzz==3.10.0",
        "referencing==0.35.1",
        "rich==13.9.2",
        "rpds-py==0.20.0",
        "seqconverter==3.3.1",
        "sequencelib==2.22.0",
        "smmap==5.0.1",
        "stqdm==0.0.5",
        "streamlit==1.39.0",
        "tenacity==9.0.0",
        "toml==0.10.2",
        "tornado==6.4.1",
        "tqdm==4.66.5",
        "update-checker==0.18.0",
        "watchdog==6.0.0",
    ],
    include_package_data = True,
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.10',
    entry_points = {
        "console_scripts" : [
            "taxontabletools2 = taxontabletools2.__main__:main",
        ]
    },
)
